<?php

/**
 * @file
 * Administrative page callbacks for the leadboxer module.
 */

/**
 * Implements hook_admin_settings() for module settings configuration.
 */
function leadboxer_admin_settings_form($form_state) {
  $form['account'] = array(
    '#type' => 'fieldset',
    '#title' => t('General settings'),
  );

  $form['account']['leadboxer_dataset_id'] = array(
    '#title' => t('LeadBoxer dataset ID'),
    '#type' => 'textfield',
    '#default_value' => variable_get('leadboxer_dataset_id', ''),
    '#size' => 50,
    '#maxlength' => 40,
    '#required' => TRUE,
    '#description' => t('If you have not done so yet, start by registering for a free trial at <a href="@leadboxer">LeadBoxer</a>. You will receive an email which contains your dataset ID. To get things setup you need to copy/paste your dataset ID in the field above and click to save your settings.', array(
      '@leadboxer' => 'https://www.leadboxer.com?utm_source=drupal-plugin',
    )),
  );

  // Visibility settings.
  $form['tracking_title'] = array(
    '#type' => 'item',
    '#title' => t('Lead Pixel scope'),
  );
  $form['tracking'] = array(
    '#type' => 'vertical_tabs',
    '#attached' => array(
      'js' => array(drupal_get_path('module', 'leadboxer') . '/leadboxer.admin.js'),
    ),
  );

  // Page specific visibility configurations.
  $visibility = variable_get('leadboxer_visibility_pages', 0);
  $pages = variable_get('leadboxer_pages', LEADBOXER_PAGES);

  $form['tracking']['page_vis_settings'] = array(
    '#type' => 'fieldset',
    '#title' => t('Pages'),
    '#collapsible' => TRUE,
    '#collapsed' => TRUE,
  );
  $form['tracking']['page_vis_settings']['leadboxer_visibility_pages'] = array(
    '#type' => 'radios',
    '#title' => t('Load the Lead Pixel to specific pages'),
    '#options' => array(
      t('Every page except the listed pages'),
      t('The listed pages only'),
    ),
    '#default_value' => $visibility,
  );
  $form['tracking']['page_vis_settings']['leadboxer_pages'] = array(
    '#type' => 'textarea',
    '#title' => t('Pages'),
    '#title_display' => 'invisible',
    '#default_value' => $pages,
    '#description' => t("Specify pages by using their paths. Enter one path per line. The '*' character is a wildcard. Example paths are %blog for the blog page and %blog-wildcard for every personal blog. %front is the front page.", array(
      '%blog' => 'blog',
      '%blog-wildcard' => 'blog/*',
      '%front' => '<front>',
    )),
    '#rows' => 10,
  );

  // Render the role overview.
  $form['tracking']['role_vis_settings'] = array(
    '#type' => 'fieldset',
    '#title' => t('Roles'),
  );

  $form['tracking']['role_vis_settings']['leadboxer_visibility_roles'] = array(
    '#type' => 'radios',
    '#title' => t('Load the Lead Pixel for specific roles'),
    '#options' => array(
      t('Add to the selected roles only'),
      t('Add to every role except the selected ones'),
    ),
    '#default_value' => variable_get('leadboxer_visibility_roles', 0),
  );

  $role_options = array_map('check_plain', user_roles());
  $form['tracking']['role_vis_settings']['leadboxer_roles'] = array(
    '#type' => 'checkboxes',
    '#title' => t('Roles'),
    '#default_value' => variable_get('leadboxer_roles', array()),
    '#options' => $role_options,
    '#description' => t('If none of the roles are selected, all users will be tracked. If a user has any of the roles checked, that user will be tracked (or excluded, depending on the setting above).'),
  );

  return system_settings_form($form);
}

/**
 * Implements _form_validate().
 */
function leadboxer_admin_settings_form_validate($form, &$form_state) {
  // Trim some text values.
  $form_state['values']['leadboxer_dataset_id'] = trim($form_state['values']['leadboxer_dataset_id']);
  $form_state['values']['leadboxer_pages'] = trim($form_state['values']['leadboxer_pages']);
}
